// Copyright 2022 The casbin Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import 'package:casdoor_flutter_sdk/casdoor_flutter_sdk.dart';
import 'package:flutter/services.dart';

/// An implementation of [CasdoorFlutterSdkPlatform] that uses method channels.
class MethodChannelCasdoorFlutterSdk extends CasdoorFlutterSdkPlatform {
  MethodChannelCasdoorFlutterSdk() : super.create();

  static const MethodChannel _channel = MethodChannel('casdoor_flutter_sdk');

  @override
  Future<bool> clearCache() async {
    return await _channel
            .invokeMethod<bool>('clearCache')
            .catchError((err) => throw (Exception(err))) ??
        false;
  }

  @override
  Future<String> authenticate(CasdoorSdkParams params) async {
    return await _channel
            .invokeMethod<String>('authenticate', <String, dynamic>{
          'params': params,
        }).catchError((err) => throw (Exception(err))) ??
        '';
  }

  @override
  Future<String> getPlatformVersion() async {
    final version =
        await _channel.invokeMethod<String>('getPlatformVersion') ?? '';
    return version;
  }
}
